@@ -24,7 +24,7 @@ impl TailwindRingOffsetWidth {
     pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
         debug_assert!(arbitrary.is_none(), "forbidden arbitrary after ring-width");
         let out = match input {
-            [] => Self { width: LengthUnit::Px(3.0) },
+            [] => Self { width: LengthUnit::px(3.0) },
             [n] => {
                 let a = TailwindArbitrary::from(*n);
                 Self { width: a.as_length()? }
