@@ -16,14 +16,6 @@ impl Display for TailwindAppearance {
 
 impl TailwindInstance for TailwindAppearance {}
 
-impl Display for TailwindCursor {
-    fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
-    }
-}
-
-impl TailwindInstance for TailwindCursor {}
-
 impl Display for TailwindCaretColor {
     fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
@@ -32,22 +24,6 @@ impl Display for TailwindCaretColor {
 
 impl TailwindInstance for TailwindCaretColor {}
 
-impl Display for TailwindPointerEvents {
-    fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
-    }
-}
-
-impl TailwindInstance for TailwindPointerEvents {}
-
-impl Display for TailwindResize {
-    fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
-    }
-}
-
-impl TailwindInstance for TailwindResize {}
-
 impl Display for TailwindScroll {
     fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
