@@ -16,13 +16,13 @@ impl Display for TailwindWhiteSpace {
 
 impl TailwindInstance for TailwindWhiteSpace {}
 
-impl Display for TailwindBreak {
+impl Display for TailwindBreakWord {
     fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
         todo!()
     }
 }
 
-impl TailwindInstance for TailwindBreak {}
+impl TailwindInstance for TailwindBreakWord {}
 
 impl Display for TailwindContentElement {
     fn fmt(&self, _f: &mut Formatter<'_>) -> std::fmt::Result {
