@@ -59,7 +59,7 @@ impl TailwindInstruction {
             ["z", rest @ ..] => TailWindZIndex::parse(rest, arbitrary, self.negative)?.boxed(),
             // Flexbox & Grid
             ["basis", rest @ ..] => TailwindBasis::parse(rest, arbitrary)?.boxed(),
-            ["flex", rest @ ..] => Self::flex_adaptor(rest, arbitrary)?,
+            ["flex", rest @ ..] => flex_adaptor(rest, arbitrary)?,
             ["grow", rest @ ..] => TailWindGrow::parse(rest, arbitrary)?.boxed(),
             ["shrink", rest @ ..] => TailWindShrink::parse(rest, arbitrary)?.boxed(),
             ["order", rest @ ..] => TailWindOrder::parse(rest, arbitrary, self.negative)?.boxed(),
@@ -166,7 +166,7 @@ impl TailwindInstruction {
             ["duration", rest @ ..] => TailwindDuration::parse(rest, arbitrary)?.boxed(),
             ["ease", rest @ ..] => TailwindEase::parse(rest, arbitrary)?.boxed(),
             ["delay", rest @ ..] => TailwindDelay::parse(rest, arbitrary)?.boxed(),
-            ["animate", rest @ ..] => todo!(),
+            ["animate", rest @ ..] => TailwindAnimate::parse(rest, arbitrary)?.boxed(),
             // Transforms System
             ["scale", rest @ ..] => TailwindScale::parse(rest, arbitrary, neg)?.boxed(),
             ["rotate", rest @ ..] => TailwindRotate::parse(rest, arbitrary, neg)?.boxed(),
@@ -187,8 +187,8 @@ impl TailwindInstruction {
             ["select", rest @ ..] => TailwindSelect::parse(rest, arbitrary)?.boxed(),
             ["will", "change", rest @ ..] => TailwindWillChange::parse(rest, arbitrary)?.boxed(),
             // SVG System
-            ["fill", rest @ ..] => todo!(),
-            ["stroke", rest @ ..] => todo!(),
+            ["fill", rest @ ..] => TailwindFillColor::parse(rest, arbitrary)?.boxed(),
+            ["stroke", rest @ ..] => TailwindStroke::parse(rest, arbitrary)?,
             // Accessibility System
             ["sr", "only"] => TailwindScreenReader::new(true).boxed(),
             ["not", "sr", "only"] => TailwindScreenReader::new(false).boxed(),
@@ -201,9 +201,9 @@ impl TailwindInstruction {
     fn break_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // https://tailwindcss.com/docs/border-style
-            ["normal"] => TailwindBreak::Normal.boxed(),
-            ["words"] => TailwindBreak::Words.boxed(),
-            ["all"] => TailwindBreak::All.boxed(),
+            ["normal"] => TailwindBreakWord::Normal.boxed(),
+            ["words"] => TailwindBreakWord::Words.boxed(),
+            ["all"] => TailwindBreakWord::All.boxed(),
             // https://tailwindcss.com/docs/break-before
             ["before", rest @ ..] => TailwindBreakBefore::parse(rest, arbitrary)?.boxed(),
             // https://tailwindcss.com/docs/break-inside
@@ -293,31 +293,6 @@ impl TailwindInstruction {
         };
         Ok(out)
     }
-    #[inline]
-    fn flex_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        let out = match str {
-            // https://tailwindcss.com/docs/display#flex
-            // `[]` => This won't happen
-            // https://tailwindcss.com/docs/flex#arbitrary-values
-            [] => TailwindFlex::parse_arbitrary(arbitrary)?.boxed(),
-            // https://tailwindcss.com/docs/flex-direction
-            ["row"] => TailwindFlexDirection::Row.boxed(),
-            ["row", "reverse"] => TailwindFlexDirection::RowReverse.boxed(),
-            ["col"] => TailwindFlexDirection::Column.boxed(),
-            ["col", "reverse"] => TailwindFlexDirection::ColumnReverse.boxed(),
-            // https://tailwindcss.com/docs/flex-wrap
-            ["wrap"] => TailwindFlexWrap::Wrap.boxed(),
-            ["wrap", "reverse"] => TailwindFlexWrap::WrapReverse.boxed(),
-            ["nowrap"] => TailwindFlexWrap::NoWrap.boxed(),
-            // https://tailwindcss.com/docs/flex
-            ["auto"] => TailwindFlex::Inherit.boxed(),
-            ["initial"] => TailwindFlex::Inherit.boxed(),
-            ["none"] => TailwindFlex::None.boxed(),
-            [n] => TailwindFlex::parse(n)?.boxed(),
-            _ => return syntax_error!("Unknown box instructions: {}", str.join("-")),
-        };
-        Ok(out)
-    }
 
     #[inline]
     fn justify_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
